@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -54,7 +53,7 @@
  *
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  * @author Martin Pala <martinp@tildeslash.com>
- * @version \$Id: event.c,v 1.64 2007/01/03 09:31:01 martinp Exp $
+ * @version \$Id: event.c,v 1.66 2007/07/25 12:54:28 hauk Exp $
  * @file
  */
 
@@ -347,12 +346,16 @@ short Event_check_state(Event_T E, short S) {
   int       i;
   int       count = 0;
   Action_T  action;
+  Service_T service;
   long long flag;
 
   ASSERT(E);
 
+  if(!(service = Event_get_source(E)))
+    return TRUE;
+
   /* Only the true failed state condition can change the initial state */
-  if(S == STATE_PASSED && E->state == STATE_INIT)
+  if(S == STATE_PASSED && E->state == STATE_INIT && !(service->error & E->id))
   {
     return FALSE;
   }
