@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -43,7 +42,6 @@ static void _gcdevice(Device_T *);
 static void _gcicmp(Icmp_T *);
 static void _gcpql(Resource_T *);
 static void _gcptl(Timestamp_T *);
-static void _gccmd(Command_T *);
 static void _gc_action(Action_T *);
 static void _gc_eventaction(EventAction_T *);
 static void _gc_event(Event_T *);
@@ -68,7 +66,7 @@ static void _gc_request(Request_T *);
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: gc.c,v 1.68 2007/01/03 09:31:01 martinp Exp $
+ *  @version \$Id: gc.c,v 1.73 2007/10/02 20:58:51 martinp Exp $
  *
  *  @file
  */
@@ -135,6 +133,19 @@ void gc_mail_list(Mail_T *m) {
 }
 
 
+void _gccmd(Command_T *c) {
+
+  int i;
+  
+  ASSERT(c&&*c);
+  
+  for(i= 0; (*c)->arg[i]; i++)
+    FREE((*c)->arg[i]);
+  FREE(*c);
+
+}
+
+
 /* ----------------------------------------------------------------- Private */
 
 
@@ -178,7 +189,7 @@ static void _gc_service(Service_T *s) {
   if((*s)->sizelist)
     _gcso(&(*s)->sizelist);
 
-    if((*s)->matchlist)
+  if((*s)->matchlist)
     _gcmatch(&(*s)->matchlist);
 
   if((*s)->checksum)
@@ -290,24 +301,14 @@ static void _gc_mail_server(MailServer_T *s) {
     _gc_mail_server(&(*s)->next);
   
   FREE((*s)->host);
+  FREE((*s)->username);
+  FREE((*s)->password);
+  FREE((*s)->ssl.certmd5);
   FREE(*s);
 
 }
 
    
-static void _gccmd(Command_T *c) {
-
-  int i;
-  
-  ASSERT(c&&*c);
-  
-  for(i= 0; (*c)->arg[i]; i++)
-    FREE((*c)->arg[i]);
-  FREE(*c);
-
-}
-
-
 static void _gc_action(Action_T *a) {
 
   ASSERT(a&&*a);
@@ -470,11 +471,15 @@ static void _gcmatch(Match_T *s) {
 
   if((*s)->match_path)
       FREE((*s)->match_path);
+
   if((*s)->match_string)
       FREE((*s)->match_string);
+
 #ifdef HAVE_REGEX_H
-  if((*s)->regex_comp)
+  if((*s)->regex_comp) {
+      regfree((*s)->regex_comp);
       FREE((*s)->regex_comp);
+  }
 #endif
   
   FREE(*s);
