@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -73,8 +72,6 @@
 
 /* URL Commands supported */
 #define HOME        "/"
-#define STOP        "/_stop"
-#define VALIDATE    "/_validate"
 #define TEST        "/_monit"
 #define ABOUT       "/_about"
 #define PING        "/_ping"
@@ -98,10 +95,10 @@ static void do_home_process(HttpRequest, HttpResponse);
 static void do_home_host(HttpRequest, HttpResponse);
 static void do_about(HttpRequest, HttpResponse);
 static void do_ping(HttpRequest, HttpResponse);
-static void not_found(HttpRequest, HttpResponse);
 static void do_runtime(HttpRequest, HttpResponse);
 static void do_viewlog(HttpRequest, HttpResponse);
 static void handle_action(HttpRequest, HttpResponse);
+static void handle_run(HttpRequest, HttpResponse);
 static void is_monit_running(HttpRequest, HttpResponse);
 static void do_service(HttpRequest, HttpResponse, Service_T);
 static void print_alerts(HttpResponse, Mail_T);
@@ -146,7 +143,7 @@ static char *get_service_status_text(Service_T);
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: cervlet.c,v 1.218 2007/02/07 23:02:58 martinp Exp $
+ *  @version \$Id: cervlet.c,v 1.224 2007/10/02 21:35:16 martinp Exp $
  *
  *  @file
  */
@@ -175,7 +172,11 @@ void init_service() {
  */
 static void doPost(HttpRequest req, HttpResponse res) {
 
-  doGet(req, res);
+  if(ACTION(RUN)) {
+    handle_run(req, res);
+  } else {
+    handle_action(req, res);
+  }
 
 }
 
@@ -193,9 +194,7 @@ static void doGet(HttpRequest req, HttpResponse res) {
       do_home(req, res);
     END_LOCK;
   } else if(ACTION(RUN)) {
-    LOCK(Run.mutex)
-      do_runtime(req, res);
-    END_LOCK;
+    handle_run(req, res);
   } else if(ACTION(TEST)) {
     is_monit_running(req, res);
   } else if(ACTION(VIEWLOG)) {
@@ -204,23 +203,6 @@ static void doGet(HttpRequest req, HttpResponse res) {
     do_about(req, res);
   } else if(ACTION(PING)) {
     do_ping(req, res);
-  } else if(ACTION(STOP)) {
-    if(is_readonly(req)) {
-      send_error(res, SC_FORBIDDEN,
-		 "You do not have sufficent privilegs to access this page");
-    } else {
-      send_error(res, SC_SERVICE_UNAVAILABLE,
-		 "The monit http server is stopped");
-      stop_httpd();
-    }
-  } else if(ACTION(VALIDATE)) {
-    if(is_readonly(req)) {
-      send_error(res, SC_FORBIDDEN,
-		 "You do not have sufficent privilegs to access this page");
-    } else {
-      do_wakeupcall();
-      send_redirect(res, ".");
-    }
   } else if(ACTION(PIXEL)) {
     printPixel(res);
   } else if(ACTION(STATUS)) {
@@ -308,7 +290,7 @@ static void do_about(HttpRequest req, HttpResponse res) {
   out_print(res,
     "<p>This program is free software; you can redistribute it and/or "
     "modify it under the terms of the GNU General Public License "
-    "as published by the Free Software Foundation; either version 2 of "
+    "as published by the Free Software Foundation; either version 3 of "
     "the License, or (at your option) any later version.<p>"
     "This program is distributed in the hope that it will be useful, but "
     "WITHOUT ANY WARRANTY; without even the implied warranty of "
@@ -402,7 +384,8 @@ static void do_runtime(HttpRequest req, HttpResponse res) {
   if(Run.mailservers) {
     MailServer_T mta= Run.mailservers;
     for(mta= Run.mailservers; mta; mta= mta->next)
-	out_print(res, "%s&nbsp;", mta->host);
+	out_print(res, "%s:%d%s&nbsp;",
+          mta->host, mta->port, mta->ssl.use_ssl?"(ssl)":"");
     out_print(res, "</td></tr>");
   } else {
     out_print(res, "localhost</td></tr>");
@@ -478,8 +461,9 @@ static void do_runtime(HttpRequest req, HttpResponse res) {
       "<font size=+1 color='#f0000'>Stop monit http server?</font>"
       "</td>"
       "<td align=right>"
-      "<form method=GET action=\"_stop\">"
-      "<input type=submit value=Go style='font-size: 12pt'></font>"
+      "<form method=POST action=\"_runtime\">"
+      "<input type=hidden name=\"action\" value=\"stop\">"
+      "<input type=submit value=Go style='font-size: 12pt'>"
       "</form>"
       "</td>");
 
@@ -488,8 +472,9 @@ static void do_runtime(HttpRequest req, HttpResponse res) {
       "<font size=+1>Force validate now?</font>"
       "</td>"
       "<td align=right>"
-      "<form method=GET action=\"_validate\">"
-      "<input type=submit value=Go style='font-size: 12pt'></font>"
+      "<form method=POST action=\"_runtime\">"
+      "<input type=hidden name=\"action\" value=\"validate\">"
+      "<input type=submit value=Go style='font-size: 12pt'>"
       "</form>"
       "</td>");
 
@@ -586,41 +571,58 @@ static void do_viewlog(HttpRequest req, HttpResponse res) {
 static void handle_action(HttpRequest req, HttpResponse res) {
 
   char *name= req->url;
-  const char *action= get_parameter(req, "action");
+  const char *action;
+  Service_T s;
   
-  if(Util_existService(++name)) {
-
-    Service_T s;
-
-    if(!(s = Util_getService(name))) {
-      send_error(res, SC_BAD_REQUEST, "There is no service by that name");
+  if(!(s = Util_getService(++name))) {
+    send_error(res, SC_BAD_REQUEST, "There is no service by that name");
+    return;
+  }
+  if((action = get_parameter(req, "action"))) {
+    if(is_readonly(req)) {
+      send_error(res, SC_FORBIDDEN,
+        "You do not have sufficent privilegs to access this page");
       return;
     }
-    if(!action) {
-      do_service(req, res, s);
-    } else {
-      if(is_readonly(req)) {
-        send_error(res, SC_FORBIDDEN,
-          "You do not have sufficent privilegs to access this page");
-        return;
-      }
-      if((s->doaction = Util_getAction(action)) == ACTION_IGNORE) {
-        send_error(res, SC_BAD_REQUEST, "Invalid action");
-        return;
-      }
-      /* Set the global flag if action is pending */
-      if(s->doaction) {
-        Run.doaction = TRUE;
-      }
-      do_wakeupcall();
-      send_redirect(res, *req->url=='/'?req->url+1:req->url);
+    if((s->doaction = Util_getAction(action)) == ACTION_IGNORE) {
+      send_error(res, SC_BAD_REQUEST, "Invalid action");
+      return;
     }
-  } else {
-    not_found(req, res);
+    LogInfo("%s service '%s' on user request\n", action, s->name);
+    Run.doaction = TRUE; /* set the global flag */
+    do_wakeupcall();
   }
+  do_service(req, res, s);
 
-  reset_depend();
+}
 
+
+static void handle_run(HttpRequest req, HttpResponse res) {
+         
+  const char *action= get_parameter(req, "action");
+         
+  if(action) {
+    if(is_readonly(req)) {
+      send_error(res, SC_FORBIDDEN,
+        "You do not have sufficent privilegs to access this page");
+      return;
+    }
+    if(IS(action, "validate")) {
+      LogInfo("The monit http server woke up on user request\n");
+      do_wakeupcall();
+    } else if(IS(action, "stop")) {
+      LogInfo("The monit http server stopped on user request\n");
+      send_error(res, SC_SERVICE_UNAVAILABLE,
+        "The monit http server is stopped");
+      stop_httpd();
+      return;
+    }
+  }
+         
+  LOCK(Run.mutex)
+    do_runtime(req, res);
+  END_LOCK;
+         
 }
 
 
@@ -801,14 +803,6 @@ static void printPixel(HttpResponse res) {
 }
 
 
-static void not_found(HttpRequest req, HttpResponse res) {
-  
-  send_error(res, SC_NOT_FOUND,
-	     "The requested URL was not found on this server");
-  
-}
-
-
 static void do_home_system(HttpRequest req, HttpResponse res) {
   
   char      *status;
@@ -1079,7 +1073,7 @@ static void do_home_file(HttpRequest req, HttpResponse res) {
       
       out_print(res,
 	"<td align=\"right\">%llu&nbsp;B</td>"
-	"<td align=\"right\">%o</td>"
+	"<td align=\"right\">%04o</td>"
 	"<td align=\"right\">%d</td>"
 	"<td align=\"right\">%d</td>",
 	(unsigned long long)s->inf->st_size,
@@ -1408,27 +1402,27 @@ static void print_buttons(HttpRequest req, HttpResponse res, Service_T s) {
   /* Start program */
   if(s->start)
       out_print(res, 
-		"<td><form method=GET action=%s>"
+		"<td><form method=POST action=%s>"
 		"<input type=hidden value='start' name=action>"
 		"<input type=submit value='Start service' style='font-size: "
 		"12pt'></form></td>", s->name);
   /* Stop program */
   if(s->stop)
       out_print(res, 
-		"<td><form method=GET action=%s>"
+		"<td><form method=POST action=%s>"
 		"<input type=hidden value='stop' name=action>"
 		"<input type=submit value='Stop service' style='font-size: "
 		"12pt'></form></td>", s->name);
   /* Restart program */
   if(s->start && s->stop)
       out_print(res, 
-		"<td><form method=GET action=%s>"
+		"<td><form method=POST action=%s>"
 		"<input type=hidden value='restart' name=action>"
 		"<input type=submit value='Restart service' style='font-size: "
 		"12pt'></form></td>", s->name);
   /* (un)monitor */
   out_print(res, 
-	    "<td><form method=GET action=%s>"
+	    "<td><form method=POST action=%s>"
 	    "<input type=hidden value='%s' name=action>"
 	    "<input type=submit value='%s' style='font-size: 12pt'>"
 	    "</form></td></tr></table>",
