@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -101,7 +100,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: processor.c,v 1.57 2007/01/03 09:31:02 martinp Exp $
+ *  @version \$Id: processor.c,v 1.61 2007/10/11 20:48:06 martinp Exp $
  *
  *  @file
  */
@@ -185,19 +184,6 @@ void send_error(HttpResponse res, int code, const char *msg) {
 }
 
 
-/**
- * Sends a temporary redirect response to the client using the
- * specified redirect Location URL. The url must be absolute.
- * @param res HttpResponse object
- * @param location An absolute url to redirect to
- */
-void send_redirect(HttpResponse res, const char *location) {
-  reset_response(res);
-  set_status(res, SC_MOVED_TEMPORARILY);
-  set_header(res, "Location", location);
-}
-
-
 /**
  * Prints a string into the given HttpResponse output buffer. The
  * actual response to the client is done in the service function,
@@ -600,7 +586,7 @@ static void create_headers(HttpRequest req) {
   while(1) {
     if(! socket_readln(S, line, sizeof(line)))
 	break;
-    if(IS(line, "\r\n") || IS(line, "\n"))
+    if(!strcasecmp(line, "\r\n") || !strcasecmp(line, "\n"))
 	break;
     if(NULL != (value= strchr(line, ':'))) {
       NEW(header);
