@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -80,7 +79,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: log.c,v 1.31 2007/01/03 09:31:01 martinp Exp $
+ *  @version \$Id: log.c,v 1.35 2007/07/26 07:41:32 hauk Exp $
  *
  *  @file
  */
@@ -90,7 +89,7 @@
 
 
 static FILE *LOG= NULL;
-static pthread_mutex_t log_mutex= PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t log_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 
 static struct mylogpriority {
@@ -134,7 +133,7 @@ int log_init() {
   if(!open_log()) {
     return FALSE;
   }
-
+  
   /* Register log_close to be
      called at program termination */
   atexit(log_close);
@@ -277,7 +276,7 @@ void log_close() {
     LogError("%s: Error closing the log file -- %s\n",
 	prog, STRERROR);
   }
-  pthread_mutex_destroy(&log_mutex);
+  
   LOG= NULL;
   
 }
@@ -347,7 +346,7 @@ static const char *logPriorityDescription(int p) {
     lp++;
   }
 
-  return NULL;
+  return "unknown";
 
 }
 
