@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -59,6 +58,10 @@
 #include <syslog.h>
 #endif
 
+#ifdef HAVE_LIMITS_H
+#include <limits.h>
+#endif
+
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
@@ -88,6 +91,7 @@
 #define LOCALHOST          "localhost"
 
 #define PORT_SMTP          25
+#define PORT_SMTPS         465
 #define PORT_HTTP          80
 #define PORT_HTTPS         443
 
@@ -165,7 +169,9 @@
 #define HASH_UNKNOWN       0
 #define HASH_MD5           1
 #define HASH_SHA1          2
-#define DEFAULT_HASH       HASH_MD5
+#define DEFAULT_HASH       HASH_MD5   
+/* Length of the longest message digest in bytes */
+#define MD_SIZE            65
 
 #define PROTOCOL_NULL      0
 #define PROTOCOL_HTTP      1
@@ -182,7 +188,8 @@
 #define HANDLER_COLLECTOR  0x2
 #define HANDLER_MAX        HANDLER_COLLECTOR
 
-#define ATTEMPT_COUNT      3
+#define ICMP_ATTEMPT_COUNT      3         
+#define ICMP_MAX_COUNT          20
 
 /** ------------------------------------------------- Special purpose macros */
 
@@ -227,11 +234,15 @@ Sigfunc *signal(int signo, Sigfunc * func);
 /** ------------------------------------------ Simple Assert Exception macro */
 
 
-#define ASSERT(e) if(!(e)) { LogCritical("AssertException: at %s:%d\naborting..\n", \
-    __FILE__, __LINE__); abort(); }
+#define ASSERT(e) if(!(e)) { LogCritical("AssertException: " #e \
+        " at %s:%d\naborting..\n", __FILE__, __LINE__); abort(); }
 
 
 /* --------------------------------------------------------- Data structures */
+           
+
+/** Message Digest type with size for the longest digest we will compute */
+typedef char MD_T[MD_SIZE];
 
 
 /**
@@ -258,7 +269,7 @@ typedef struct myaction {
     Command_T exec;                    /**< Optional command to be executed  */
     unsigned  count;           /**< Event count needed to trigger the action */
     unsigned  cycles;    /**< Cycles during which count limit can be reached */
-    char description[STRLEN];                 /**< Action description buffer */
+    char description[PATH_MAX];               /**< Action description buffer */
 } *Action_T;
 
 
@@ -324,6 +335,10 @@ typedef struct mymail {
 typedef struct mymailserver {
   char *host;     /**< Server host address, may be a IP or a hostname string */
   int   port;                                               /**< Server port */
+  char *username;                               /** < Username for SMTP_AUTH */
+  char *password;                               /** < Password for SMTP_AUTH */
+  Ssl_T ssl;                                             /**< SSL definition */
+
   /** For internal use */
   struct mymailserver *next;        /**< Next server to try on connect error */
 } *MailServer_T;
@@ -710,7 +725,7 @@ typedef struct myevent *Event_T;
 
 /** Defines data for application runtime */
 struct myrun {
-  int  stopped;         /**< TRUE if monit was stopped. Flag used by threads */
+  volatile int  stopped;/**< TRUE if monit was stopped. Flag used by threads */
   char *controlfile;                /**< The file to read configuration from */
   char *logfile;                         /**< The file to write logdata into */
   char *localhostname;                      /**< The host name for localhost */
@@ -735,8 +750,8 @@ struct myrun {
   int  facility;              /** The facility to use when running openlog() */
   int  doprocess;                 /**< TRUE if process status engine is used */
   char *bind_addr;                  /**< The address monit http will bind to */
-  int  doreload;             /**< TRUE if a monit daemon should reinitialize */
-  int  dowakeup;           /**< TRUE if a monit daemon was wake up by signal */
+  volatile int  doreload;    /**< TRUE if a monit daemon should reinitialize */
+  volatile int  dowakeup;  /**< TRUE if a monit daemon was wake up by signal */
   int  doaction;             /**< TRUE if some service(s) has action pending */
   mode_t umask;                /**< The initial umask monit was started with */
   int  testing;   /**< Running in configuration testing mode - TRUE or FALSE */
@@ -816,6 +831,7 @@ void  validate() ;
 void  daemonize() ;
 void  gc();
 void  gc_mail_list(Mail_T *);
+void _gccmd(Command_T *);
 int   kill_daemon(int);
 int   exist_daemon(); 
 int   sendmail(Mail_T);
