@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -134,7 +133,7 @@
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: net.c,v 1.75 2007/01/03 09:31:01 martinp Exp $
+ *  @version \$Id: net.c,v 1.77 2007/10/02 13:58:49 hauk Exp $
  *
  *  @file
  */
@@ -634,11 +633,11 @@ double icmp_echo(const char *hostname, int timeout, int count) {
 #ifdef HAVE_SOL_IP
   struct iphdr *iphdrin;
   struct icmphdr *icmphdrin= NULL;
-  struct icmphdr *icmphdrout[count];
+  struct icmphdr *icmphdrout[ICMP_MAX_COUNT];
 #else
   struct ip *iphdrin;
   struct icmp *icmphdrin= NULL;
-  struct icmp *icmphdrout[count];
+  struct icmp *icmphdrout[ICMP_MAX_COUNT];
 #endif
   fd_set rset;
   int i;
@@ -648,11 +647,12 @@ double icmp_echo(const char *hostname, int timeout, int count) {
   unsigned ttl= 255;
   char buf[STRLEN];
   struct timeval tv;
-  struct timeval t1[count];
+  struct timeval t1[ICMP_MAX_COUNT];
   struct timeval t2;
   double response= -1;
   
-  ASSERT(hostname);
+  ASSERT(hostname);   
+  ASSERT(count <= ICMP_MAX_COUNT);
 
   if((hp= gethostbyname(hostname)) == NULL)
     return response;
@@ -677,7 +677,7 @@ double icmp_echo(const char *hostname, int timeout, int count) {
 
   tv.tv_sec= timeout;
   tv.tv_usec= 0;
-
+  
   for(i=0; i<count; i++) {
     NEW(icmphdrout[i]);
 #ifdef HAVE_SOL_IP
@@ -760,7 +760,7 @@ double icmp_echo(const char *hostname, int timeout, int count) {
   done:
   for(i=0; i<count; i++) {
     FREE(icmphdrout[i]);
-  }
+  }    
   close_socket(s);
 
   return response;
