@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -66,7 +65,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: postfix_policy.c,v 1.5 2007/01/03 09:31:02 martinp Exp $
+ *  @version \$Id: postfix_policy.c,v 1.7 2007/10/11 19:57:17 martinp Exp $
  *
  *  @file
  */
@@ -98,7 +97,7 @@ int check_postfix_policy(Socket_T s) {
 
   if( (strlen(buf) <= 7) || strncasecmp(buf, "action=", 7) ) {
     LogError("POSTFIX-POLICY error: %s\n",
-      (buf && *buf)?buf:"no action returned");
+      *buf?buf:"no action returned");
     return FALSE;
   }
   
