@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -50,7 +49,7 @@
  * Implementation of the socket interface.
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.c,v 1.58 2007/01/03 09:31:01 martinp Exp $
+ * @version \$Id: socket.c,v 1.63 2007/10/02 13:58:49 hauk Exp $
  * @file
  */
 
@@ -103,7 +102,11 @@ static int fill(Socket_T S, int timeout);
 Socket_T socket_new(const char *host, int port, int type, int use_ssl,
                     int timeout) {
   
-  Ssl_T ssl= {use_ssl, SSL_VERSION_AUTO, NULL};
+  Ssl_T ssl;    
+  
+  ssl.use_ssl= use_ssl;
+  ssl.version= SSL_VERSION_AUTO;
+  ssl.certmd5= NULL;
   
   return socket_create_t(host, port, type, ssl, timeout);
   
@@ -141,32 +144,16 @@ Socket_T socket_create(void *port) {
       S->host= xstrdup(p->hostname);
     }
     
-    if(p->SSL.use_ssl) {
-      if(! (S->ssl= new_ssl_connection(NULL, p->SSL.version))) {
-        goto ssl_error;
-      }
-      if(! embed_ssl_socket(S->ssl, S->socket)) {
-        goto ssl_error;
-      }
-      if(p->SSL.certmd5) {
-        if(! check_ssl_md5sum(S->ssl, p->SSL.certmd5)) {
-          goto ssl_error;
-        }
-      }
+    if(p->SSL.use_ssl && !socket_switch2ssl(S, p->SSL)) {
+      socket_free(&S);
+      return NULL;
     }
     
     S->Port= port;
-    
     return S;
-    
-ssl_error:
-      socket_free(&S);
-    return NULL;
-    
   }
   
   return NULL;
-  
 }
 
 
@@ -177,7 +164,7 @@ ssl_error:
  * may be a hostname found in the DNS or an IP address string.
  * @param port The port number to connect to
  * @param type The socket type to use (SOCKET_TCP or SOCKET_UPD)
- * @param use_ssl if TRUE the socket is created supporting SSL
+ * @param ssl Options for SSL
  * @param timeout The timeout value in seconds
  * @return The connected Socket or NULL if an error occurred
  */
@@ -208,30 +195,15 @@ Socket_T socket_create_t(const char *host, int port, int type, Ssl_T ssl,
     S->host= xstrdup(host);
     S->connection_type= TYPE_LOCAL;
     
-    if(ssl.use_ssl) {
-      if(! (S->ssl= new_ssl_connection(NULL, ssl.version))) {
-        goto ssl_error;
-      }
-      if(! embed_ssl_socket(S->ssl, S->socket)) {
-        goto ssl_error;
-      }
-      if(ssl.certmd5) {
-        if(! check_ssl_md5sum(S->ssl, ssl.certmd5)) {
-          goto ssl_error;
-        }
-      }
+    if(ssl.use_ssl && !socket_switch2ssl(S, ssl)) {
+      socket_free(&S);
+      return NULL;
     }
     
     return S;
-    
-ssl_error:
-      socket_free(&S);
-    return NULL;
-    
   }
   
   return NULL;
-  
 }
 
 
@@ -416,6 +388,29 @@ const char *socket_get_remote_host(Socket_T S) {
 /* ---------------------------------------------------------------- Public */
 
 
+/**
+ * Switches a connected socket to ssl.
+ * @param S The already connected socket
+ * @param ssl Options for ssl
+ * @return TRUE if ssl is ready otherwise FALSE
+ */
+int socket_switch2ssl(Socket_T S, Ssl_T ssl)  {
+
+  if(! (S->ssl= new_ssl_connection(NULL, ssl.version)))
+    return FALSE;
+
+  if(! embed_ssl_socket(S->ssl, S->socket))
+    return FALSE;
+
+  if(ssl.certmd5 && !check_ssl_md5sum(S->ssl, ssl.certmd5)) {
+    LogError("md5sum of certificate does not match!");
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
+
 /**
  * Writes a character string. Use this function to send text based
  * messages to a client.
@@ -574,7 +569,7 @@ void socket_reset(Socket_T S) {
 
   ASSERT(S);
   
-  /* Also throw away any pending incomming data */
+  /* Throw away any pending incomming data */
   while(fill(S, 0) > 0);
   S->offset= 0;
   S->length= 0;
@@ -606,10 +601,10 @@ static int fill(Socket_T S, int timeout) {
   while(RBUFFER_SIZE > S->length) {
     
     if(S->ssl) {
-      n= recv_ssl_socket(S->ssl, &S->buffer[S->length], 
+      n= recv_ssl_socket(S->ssl, S->buffer + S->length, 
                          RBUFFER_SIZE-S->length, timeout);
     } else {
-      n= sock_read(S->socket, &S->buffer[S->length], 
+      n= sock_read(S->socket, S->buffer + S->length, 
                    RBUFFER_SIZE-S->length, timeout);
     }
     
@@ -618,15 +613,12 @@ static int fill(Socket_T S, int timeout) {
     if(n > 0) {
       S->length+= n;
       continue;
-    }
-    
-    if(n==0) break;
-        
-    if(n < 0) {
+    }  else if(n < 0) {
       if(errno == EAGAIN || errno == EWOULDBLOCK || S->type==SOCK_DGRAM) break;
       return -1;
-    }
-    
+    } else
+      break;
+
   }
   
   return S->length;
