@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -30,7 +29,7 @@
  * communication between two machines. 
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.h,v 1.23 2007/01/03 09:31:01 martinp Exp $
+ * @version \$Id: socket.h,v 1.27 2007/09/05 08:43:36 hauk Exp $
  * @file
  */
 
@@ -71,7 +70,7 @@ Socket_T socket_create(void *port);
  * may be a hostname found in the DNS or an IP address string.
  * @param port The port number to connect to
  * @param type The socket type to use (SOCKET_TCP or SOCKET_UPD)
- * @param ssl If defined the socket is created supporting SSL
+ * @param ssl Options for SSL
  * @param timeout The timeout value in seconds
  * @return The connected Socket or NULL if an error occurred
  */
@@ -154,6 +153,15 @@ int socket_get_remote_port(Socket_T S);
 const char *socket_get_remote_host(Socket_T S);
 
 
+/**
+ * Switches a connected socket to ssl.
+ * @param S The already connected socket
+ * @param ssl Options for ssl
+ * @return TRUE if ssl is ready otherwise FALSE
+ */
+int socket_switch2ssl(Socket_T S, Ssl_T ssl);
+
+
 /**
  * Writes a character string. Use this function to send text based
  * messages to a client.
