@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -119,7 +118,7 @@ static int is_url_unsafe(unsigned char *);
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.c,v 1.192 2007/02/02 09:57:12 martinp Exp $
+ *  @version \$Id: util.c,v 1.199 2007/10/16 03:05:41 hauk Exp $
  *  @file
  */
 
@@ -367,11 +366,11 @@ int Util_countWords(char *s, const char *word) {
  */
 int Util_startsWith(const char *a, const char *b) {
 
-  if((!a || !b) || toupper(*a)!=toupper(*b)) return FALSE;
+  if((!a || !b) || toupper((int)*a)!=toupper((int)*b)) return FALSE;
 
   while(*a && *b) {
     
-    if(toupper(*a++) != toupper(*b++)) return FALSE;
+    if(toupper((int)*a++) != toupper((int)*b++)) return FALSE;
     
   }
 
@@ -500,6 +499,27 @@ int Util_handle0Escapes(char *buf) {
 }
 
 
+/**
+ * Convert a digest buffer to a char string
+ * @param digest buffer containing a MD digest
+ * @param mdlen digest length
+ * @param result buffer to write the result to. Must be at least
+ * 41 bytes long.
+ */
+char *Util_digest2Bytes(unsigned char *digest, int mdlen, MD_T result) {
+        int i;
+        unsigned char *tmp= (unsigned char*)result;
+        static unsigned char hex[] = "0123456789abcdef";     
+        ASSERT(mdlen * 2 < MD_SIZE); // Overflow guard
+        for(i= 0; i < mdlen; i++) {
+                *tmp++ = hex[digest[i] >> 4];
+                *tmp++ = hex[digest[i] & 0xf];
+        }
+        *tmp = '\0';
+        return result;
+}
+
+
 /**
  * @param name A service name as stated in the config file
  * @return the named service or NULL if not found
@@ -541,15 +561,9 @@ int Util_getNumberOfServices() {
  */
 int Util_existService(const char *name) {
 
-  Service_T s;
-
   ASSERT(name);
 
-  for(s= servicelist; s; s= s->next)
-      if(IS(s->name, name))
-	  return TRUE;
-
-  return FALSE;
+  return Util_getService(name)?TRUE:FALSE;
 
 }
 
@@ -604,7 +618,11 @@ void Util_printRunList() {
   if(Run.mailservers) {
     MailServer_T mta= Run.mailservers;
     for(mta= Run.mailservers; mta; mta= mta->next)
-	printf("%s%s", mta->host, mta->next?", ":" ");
+	printf("%s:%d%s%s",
+          mta->host,
+          mta->port,
+          mta->ssl.use_ssl?"(ssl)":"",
+          mta->next?", ":" ");
     printf("\n");
   } else {
     printf("localhost\n");
@@ -778,7 +796,7 @@ void Util_printService(Service_T s) {
     Util_getEventratio(a->failed, ratio1);
     Util_getEventratio(a->passed, ratio2);
 
-    printf(" %-20s = if failed %o %s then %s else if passed %s then %s\n",
+    printf(" %-20s = if failed %04o %s then %s else if passed %s then %s\n",
       "Permission", s->perm->perm,
       ratio1, a->failed->description,
       ratio2, a->passed->description);
@@ -1203,11 +1221,11 @@ pid_t Util_getPid(char *pidfile) {
 	prog, pidfile, STRERROR);
     return FALSE ;
   }
+
   fscanf(file, "%d", &pid);
   fclose(file);
+
   if(pid == -1) {
-    LogError("%s: pidfile `%s' does not contain a valid pidnumber\n",
-	prog, pidfile);
     return (FALSE);
   }
   
@@ -1328,56 +1346,54 @@ char *Util_getUptime(time_t delta, char *sep) {
 /**
  * @return a checksum for the given file, or NULL if error.
  */
-char *Util_getChecksum(char *file, int hashtype) {
+ char *Util_getChecksum(char *file, int hashtype) {
 
-  int hashlength=16;
+   int hashlength=16;
 
-  ASSERT(file);
-  
-  switch(hashtype) {
-  case HASH_MD5:
-    hashlength=16;
-    break;
-  case HASH_SHA1:
-    hashlength=20;
-    break;
-  default:
-    return NULL;
-  }
-  
-  if(File_isFile(file)) {
-    FILE *f= fopen(file, "r");
-    if(f) {
-      int i;
-      unsigned char buf[hashlength];
-      char result[STRLEN];
-      char *r= result;
-      int fresult=0;
-      
-      *result=0;
-      
-      switch(hashtype) {
-      case HASH_MD5:
-	fresult=md5_stream(f, buf);
-	break;
-      case HASH_SHA1:
-	fresult=sha_stream(f, buf);
-	break;
-      }
-      
-      fclose(f);
-      if(fresult) {
-	return NULL;
-      }
-      for(i= 0; i < hashlength; ++i)
-	r+= snprintf(r, STRLEN-(r-result) ,"%02x", buf[i]);
-      
-      return (xstrdup(result));
-      
-    }
-  }
-  return NULL;
-}
+   ASSERT(file);
+
+   switch(hashtype) {
+     case HASH_MD5:
+     hashlength=16;
+     break;
+     case HASH_SHA1:
+     hashlength=20;
+     break;
+     default:
+     return NULL;
+   }
+
+   if(File_isFile(file)) {
+     FILE *f= fopen(file, "r");
+     if(f) {
+       MD_T result;
+       unsigned char buf[STRLEN];
+       int fresult=0;
+
+       *result=0;
+
+       switch(hashtype) {
+         case HASH_MD5:
+         fresult=md5_stream(f, buf);
+         break;
+         case HASH_SHA1:
+         fresult=sha_stream(f, buf);
+         break;
+       }
+
+       fclose(f);
+       if(fresult) {
+         return NULL;
+       }
+
+       return (xstrdup(Util_digest2Bytes(buf, hashlength, result)));
+
+     }
+   }
+
+   return NULL;
+
+ }
 
 
 /**
