@@ -2,19 +2,18 @@
  * Copyright (C), 2000-2007 by the monit project group.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -91,7 +90,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: validate.c,v 1.163 2007/01/29 18:10:32 martinp Exp $
+ *  @version \$Id: validate.c,v 1.167 2007/10/06 20:33:05 martinp Exp $
  *  @file
  */
 
@@ -659,9 +658,6 @@ static void check_process_state(Service_T s) {
   ASSERT(s);
 
   if(s->inf->status_flag & PROCESS_ZOMBIE) {
-    /* We do not check the process anymore if it's a zombie
-       since such a process is (usually) unmanageable */
-    Util_monitorUnset(s);
     Event_post(s, EVENT_DATA, STATE_FAILED, s->action_DATA,
       "'%s' process with pid %d is a zombie", s->name, s->inf->pid);
   } else {
@@ -1016,10 +1012,10 @@ static void check_perm(Service_T s) {
 
   if((s->inf->st_mode & 07777) != s->perm->perm) {
     Event_post(s, EVENT_PERMISSION, STATE_FAILED, s->perm->action,
-      "'%s' permission test failed for %s -- current permission is %o",
+      "'%s' permission test failed for %s -- current permission is %04o",
       s->name, s->path, s->inf->st_mode&07777);
   } else {
-    DEBUG("'%s' permission check passed [current permission=%o]\n",
+    DEBUG("'%s' permission check passed [current permission=%04o]\n",
       s->name, s->inf->st_mode&07777);
     Event_post(s, EVENT_PERMISSION, STATE_PASSED, s->perm->action,
       "'%s' permission passed", s->name);
@@ -1092,10 +1088,10 @@ static void check_timestamp(Service_T s) {
       /* if we are testing for changes only, the value is variable */
 
       if(t->timestamp != s->inf->timestamp) {
+        /* reset expected value for next cycle */
         t->timestamp= s->inf->timestamp;
         Event_post(s, EVENT_CHANGED, STATE_FAILED, t->action,
           "'%s' timestamp was changed for %s", s->name, s->path);
-        /* reset expected value for next cycle */
       } else {
         DEBUG("'%s' timestamp was not changed for %s\n", s->name, s->path);
         Event_post(s, EVENT_CHANGED, STATE_PASSED, t->action,
